package eu.maiora.model

import eu.maiora.db.*
import org.jetbrains.exposed.sql.insertAndGetId
import org.jetbrains.exposed.sql.update

class PrenotazioniPastiDettaglioRepositoryImpl : PrenotazioniPastiDettaglioRepository {
    override suspend fun insert(prenotazionePastoDettaglio : PrenotazioniPastiDettaglio): PrenotazioniPastiDettaglio = suspendTransaction {
        // Inserisci un nuovo dettaglio di una prenotazione pasto
        // ID non definito: viene gestito dalla sequence
        val idPrenPastiDettInserted = PrenotazioniPastiDettaglioTable.insertAndGetId {
            it[idPrenotazione] = prenotazionePastoDettaglio.idPrenotazione
            it[idProdotto] = prenotazionePastoDettaglio.idProdotto
            it[idStato] = prenotazionePastoDettaglio.idStato
        }.value

        PrenotazioniPastiDettaglio(
            idPrenPastiDettInserted,
            prenotazionePastoDettaglio.idPrenotazione,
            prenotazionePastoDettaglio.idProdotto,
            prenotazionePastoDettaglio.idStato
        )
    }

    override suspend fun update (prenotazionePastoDettaglio : PrenotazioniPastiDettaglio): PrenotazioniPastiDettaglio = suspendTransaction {
        PrenotazioniPastiDettaglioTable.update({PrenotazioniPastiDettaglioTable.id eq prenotazionePastoDettaglio.id}){
            it[idPrenotazione] = prenotazionePastoDettaglio.idPrenotazione
            it[idProdotto] = prenotazionePastoDettaglio.idProdotto
            it[idStato] = prenotazionePastoDettaglio.idStato
        }

        prenotazionePastoDettaglio
    }

    override suspend fun listaDettagliByIdPrenotazione(idPrenotazione : Long): List<PrenotazioniPastiDettaglio> = suspendTransaction {
        // Cerca la lista di dettagli della prenotazione (ovvero i prodotti)
        PrenotazioniPastiDettaglioDao.find { PrenotazioniPastiDettaglioTable.idPrenotazione eq idPrenotazione }
            .toList() // Restituisce la lista dei prodotti
            .map { prenotazioniPastiDettaglioDaoToModel(it) } // Converte il DAO in un oggetto PrenotazioniPastiDettaglio

    }
}