package eu.maiora.routes

import eu.maiora.model.MovimentiRepositoryImpl
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.auth.*
import io.ktor.server.response.*
import io.ktor.server.routing.*


fun Route.movimenti(movimentiRepository: MovimentiRepositoryImpl){
    route("/api/movimenti"){
        authenticate("auth-jwt") {
            get("{idTessera}"){
                // Ottieni l'id della tessera dal percorso
                val idTessera = call.parameters["idTessera"]

                if (idTessera == null) {
                    call.respondText("ID tessera non valido", status = HttpStatusCode.BadRequest)
                    return@get
                }

                // Cerca la tessera per codice fiscale
                val listaMovimenti = movimentiRepository.movimentiByIdTessera(idTessera.toLong())


                if (listaMovimenti != null) {
                    call.respond(listaMovimenti)
                } else {
                    call.respondText("Movimenti non trovati", status = HttpStatusCode.NotFound)
                }
            }
        }

    }
}